SystemOrganization addCategory: #ConfigurationOfAltBrowser!

Object subclass: #ConfigurationOfAltBrowser
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfAltBrowser'!

!ConfigurationOfAltBrowser commentStamp: '<historical>' prior: 0!
AltBrowser: a tree-based system browser for Pharo with smart suggestions, refactoring integration including environment filtering, and git integration.

It integrates: the finder, message browser and the usual system browser.!

!ConfigurationOfAltBrowser class methodsFor: 'development support' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfAltBrowser class methodsFor: 'private' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfAltBrowser class methodsFor: 'private' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfAltBrowser class methodsFor: 'private' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfAltBrowser class methodsFor: 'metacello tool support' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfAltBrowser class methodsFor: 'loading' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfAltBrowser class methodsFor: 'loading' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfAltBrowser class methodsFor: 'loading' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfAltBrowser class methodsFor: 'accessing' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
project

	^self new project! !

!ConfigurationOfAltBrowser class methodsFor: 'development support' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfAltBrowser methodsFor: 'baseline' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
baseline01: spec
	<version: '0.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec repository: 'http://smalltalkhub.com/mc/ThierryGoubier/AltBrowser/main/'.

		spec
			package: 'Alt-Browser'.
		
		spec
			group: 'default' with: #('Alt-Browser')
		]! !

!ConfigurationOfAltBrowser methodsFor: 'accessing' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfAltBrowser methodsFor: 'accessing' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfAltBrowser methodsFor: 'symbolic versions' stamp: 'ThierryGoubier 9/12/2013 09:33:13'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'pharo2.0.x' version: '0.1'.
	spec for: #'pharo3.0.x' version: '0.2'
! !

!ConfigurationOfAltBrowser methodsFor: 'versions' stamp: 'ThierryGoubier 9/25/2013 14:29'!
version01: spec
	<version: '0.1' imports: #('0.1-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #stable;
				author: 'ThierryGoubier';
				description: 'AltBrowser: a tree-based, simple and advanced system browser / message list / finder for Pharo 2.0 with smart suggestions, refactoring integration and git integration.'.
			spec package: 'Alt-Browser' with: 'Alt-Browser-ThierryGoubier.167' ]! !

!ConfigurationOfAltBrowser methodsFor: 'versions' stamp: 'ThierryGoubier 9/25/2013 14:32'!
version02: spec
	<version: '0.2' imports: #('0.1-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #stable;
				author: 'ThierryGoubier';
				description: 'AltBrowser: a tree-based, simple and advanced system browser / message list / finder for Pharo 3.0 with smart suggestions, refactoring integration and git integration'.
			spec package: 'Alt-Browser' with: 'Alt-Browser-ThierryGoubier.135' ]! !
